==> jc-1.4.0.tar.gz: java/awt/event/InputEvent.h <==
// public abstract class java.awt.event.InputEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_InputEvent_H_
#define _JC_java_awt_event_InputEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_InputEvent$sub_refs	_jc_java_awt_event_InputEvent$sub_refs;
typedef struct _jc_java_awt_event_InputEvent$sub_nonrefs	_jc_java_awt_event_InputEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_InputEvent$refs	_jc_java_awt_event_InputEvent$refs;
typedef struct _jc_java_awt_event_InputEvent$nonrefs	_jc_java_awt_event_InputEvent$nonrefs;
typedef struct _jc_java_awt_event_InputEvent$object	_jc_java_awt_event_InputEvent$object;

typedef struct _jc_java_awt_event_InputEvent$fields_struct	_jc_java_awt_event_InputEvent$fields_struct;
typedef const struct _jc_java_awt_event_InputEvent$vmethods	_jc_java_awt_event_InputEvent$vmethods;
typedef const struct _jc_java_awt_event_InputEvent$vtable	_jc_java_awt_event_InputEvent$vtable;
typedef const struct _jc_java_awt_event_InputEvent$vtype	_jc_java_awt_event_InputEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_InputEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ALT__5fDOWN__5fMASK;
	jint	ALT__5fGRAPH__5fDOWN__5fMASK;
	jint	ALT__5fGRAPH__5fMASK;
	jint	ALT__5fMASK;
	jint	BUTTON1__5fDOWN__5fMASK;
	jint	BUTTON1__5fMASK;
	jint	BUTTON2__5fDOWN__5fMASK;
	jint	BUTTON2__5fMASK;
	jint	BUTTON3__5fDOWN__5fMASK;
	jint	BUTTON3__5fMASK;
	jint	CONVERT__5fMASK;
	jint	CTRL__5fDOWN__5fMASK;
	jint	CTRL__5fMASK;
	jint	META__5fDOWN__5fMASK;
	jint	META__5fMASK;
	jint	SHIFT__5fDOWN__5fMASK;
	jint	SHIFT__5fMASK;
};
extern _jc_java_awt_event_InputEvent$fields_struct _jc_java_awt_event_InputEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_InputEvent$method$_init$191e707ac5267411(_jc_env *, struct _jc_java_awt_event_InputEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint);

// Virtual methods
extern void _jc_java_awt_event_InputEvent$method$consume$3d554af5733d9795(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jint _jc_java_awt_event_InputEvent$method$getModifiers$d9bdcb51d9f4fabc(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jint _jc_java_awt_event_InputEvent$method$getModifiersEx$af0cff90b6920cc8(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jlong _jc_java_awt_event_InputEvent$method$getWhen$3d8a46a7284dd8d9(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jboolean _jc_java_awt_event_InputEvent$method$isAltDown$1d0c124e72ffa073(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jboolean _jc_java_awt_event_InputEvent$method$isAltGraphDown$2944a702c5d6f88d(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jboolean _jc_java_awt_event_InputEvent$method$isConsumed$98f8b0828fdde4a0(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jboolean _jc_java_awt_event_InputEvent$method$isControlDown$6e7cfe042e1bce95(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jboolean _jc_java_awt_event_InputEvent$method$isMetaDown$a5ace2167ae3a033(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
extern jboolean _jc_java_awt_event_InputEvent$method$isShiftDown$432ee7cf3fe84265(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_InputEvent$method_info$consume$3d554af5733d9795;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$getModifiers$d9bdcb51d9f4fabc;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$getModifiersEx$af0cff90b6920cc8;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$getWhen$3d8a46a7284dd8d9;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isAltDown$1d0c124e72ffa073;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isAltGraphDown$2944a702c5d6f88d;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isConsumed$98f8b0828fdde4a0;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isControlDown$6e7cfe042e1bce95;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isMetaDown$a5ace2167ae3a033;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isShiftDown$432ee7cf3fe84265;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_InputEvent$method$getModifiersExText$8e6529b787ca59a0(_jc_env *, jint);

// Virtual methods structure
struct _jc_java_awt_event_InputEvent$vmethods {
	void	(*consume$3d554af5733d9795)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jint	(*getModifiers$d9bdcb51d9f4fabc)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jint	(*getModifiersEx$af0cff90b6920cc8)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jlong	(*getWhen$3d8a46a7284dd8d9)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jboolean	(*isAltDown$1d0c124e72ffa073)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jboolean	(*isAltGraphDown$2944a702c5d6f88d)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jboolean	(*isConsumed$98f8b0828fdde4a0)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jboolean	(*isControlDown$6e7cfe042e1bce95)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jboolean	(*isMetaDown$a5ace2167ae3a033)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
	jboolean	(*isShiftDown$432ee7cf3fe84265)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *);
};

// Vtable
struct _jc_java_awt_event_InputEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
};

// Vtype
struct _jc_java_awt_event_InputEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_InputEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_InputEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_InputEvent$refs {
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_InputEvent$sub_nonrefs {
	jlong	when;
	jint	modifiers;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_InputEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
};

// Object instance structure
struct _jc_java_awt_event_InputEvent$object {
	_jc_java_awt_event_InputEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_InputEvent$vtype	*vtype;
	_jc_java_awt_event_InputEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_InputEvent$vtype _jc_java_awt_event_InputEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_InputEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_InputEvent$class_object;

#endif	/* _JC_java_awt_event_InputEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/InputEvent.h <==
// public abstract class java.awt.event.InputEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_ComponentEvent

#include "java/awt/event/ComponentEvent.h"

#ifndef _JC_java_awt_event_InputEvent_H_
#define _JC_java_awt_event_InputEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_InputEvent$sub_refs	_jc_java_awt_event_InputEvent$sub_refs;
typedef struct _jc_java_awt_event_InputEvent$sub_nonrefs	_jc_java_awt_event_InputEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_InputEvent$refs	_jc_java_awt_event_InputEvent$refs;
typedef struct _jc_java_awt_event_InputEvent$nonrefs	_jc_java_awt_event_InputEvent$nonrefs;
typedef struct _jc_java_awt_event_InputEvent$object	_jc_java_awt_event_InputEvent$object;

typedef struct _jc_java_awt_event_InputEvent$fields_struct	_jc_java_awt_event_InputEvent$fields_struct;
typedef const struct _jc_java_awt_event_InputEvent$vmethods	_jc_java_awt_event_InputEvent$vmethods;
typedef const struct _jc_java_awt_event_InputEvent$vtable	_jc_java_awt_event_InputEvent$vtable;
typedef const struct _jc_java_awt_event_InputEvent$vtype	_jc_java_awt_event_InputEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_InputEvent$fields_struct {
	jlong	serialVersionUID;
	jint	ALT__5fDOWN__5fMASK;
	jint	ALT__5fGRAPH__5fDOWN__5fMASK;
	jint	ALT__5fGRAPH__5fMASK;
	jint	ALT__5fMASK;
	jint	BUTTON1__5fDOWN__5fMASK;
	jint	BUTTON1__5fMASK;
	jint	BUTTON2__5fDOWN__5fMASK;
	jint	BUTTON2__5fMASK;
	jint	BUTTON3__5fDOWN__5fMASK;
	jint	BUTTON3__5fMASK;
	jint	CONVERT__5fMASK;
	jint	CTRL__5fDOWN__5fMASK;
	jint	CTRL__5fMASK;
	jint	META__5fDOWN__5fMASK;
	jint	META__5fMASK;
	jint	SHIFT__5fDOWN__5fMASK;
	jint	SHIFT__5fMASK;
};
extern _jc_java_awt_event_InputEvent$fields_struct _jc_java_awt_event_InputEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_InputEvent$method$_init$191e707ac5267411(_jc_env *, struct _jc_java_awt_event_InputEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_InputEvent$method$consume$3d554af5733d9795(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_InputEvent$method$getModifiers$d9bdcb51d9f4fabc(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_InputEvent$method$getModifiersEx$af0cff90b6920cc8(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_awt_event_InputEvent$method$getWhen$3d8a46a7284dd8d9(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_InputEvent$method$isAltDown$1d0c124e72ffa073(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_InputEvent$method$isAltGraphDown$2944a702c5d6f88d(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_InputEvent$method$isConsumed$98f8b0828fdde4a0(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_InputEvent$method$isControlDown$6e7cfe042e1bce95(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_InputEvent$method$isMetaDown$a5ace2167ae3a033(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_event_InputEvent$method$isShiftDown$432ee7cf3fe84265(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_InputEvent$method_info$consume$3d554af5733d9795;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$getModifiers$d9bdcb51d9f4fabc;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$getModifiersEx$af0cff90b6920cc8;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$getWhen$3d8a46a7284dd8d9;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isAltDown$1d0c124e72ffa073;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isAltGraphDown$2944a702c5d6f88d;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isConsumed$98f8b0828fdde4a0;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isControlDown$6e7cfe042e1bce95;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isMetaDown$a5ace2167ae3a033;
extern _jc_method _jc_java_awt_event_InputEvent$method_info$isShiftDown$432ee7cf3fe84265;

// Static methods
extern struct _jc_java_lang_String$object *_jc_java_awt_event_InputEvent$method$getModifiersExText$8e6529b787ca59a0(_jc_env *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_event_InputEvent$vmethods {
	void	(*consume$3d554af5733d9795)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jint	(*getModifiers$d9bdcb51d9f4fabc)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jint	(*getModifiersEx$af0cff90b6920cc8)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jlong	(*getWhen$3d8a46a7284dd8d9)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isAltDown$1d0c124e72ffa073)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isAltGraphDown$2944a702c5d6f88d)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isConsumed$98f8b0828fdde4a0)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isControlDown$6e7cfe042e1bce95)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isMetaDown$a5ace2167ae3a033)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isShiftDown$432ee7cf3fe84265)(_jc_env *, struct _jc_java_awt_event_InputEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_InputEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
};

// Vtype
struct _jc_java_awt_event_InputEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_InputEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_InputEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_InputEvent$refs {
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_InputEvent$sub_nonrefs {
	jlong	when;
	jint	modifiers;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_InputEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
};

// Object instance structure
struct _jc_java_awt_event_InputEvent$object {
	_jc_java_awt_event_InputEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_InputEvent$vtype	*vtype;
	_jc_java_awt_event_InputEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_InputEvent$vtype _jc_java_awt_event_InputEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_InputEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_InputEvent$class_object;

#endif	/* _JC_java_awt_event_InputEvent_H_ */
